Two more simple patches. The first deals with the @ALLOCA@
substitution for libtests.a. The second just bumps the Autoconf
requirement to 2.64.

Collin
From 6a59d2ca97f111c5ca7dd564c5d92f62a5e196d7 Mon Sep 17 00:00:00 2001
From: Collin Funk <collin.fu...@gmail.com>
Date: Wed, 28 Feb 2024 21:17:49 -0800
Subject: [PATCH 2/3] gnulib-tool.py: Follow gnulib-tool changes, part 34.

Follow gnulib-tool change
2017-05-15  Bruno Haible  <br...@clisp.org>
gnulib-tool: Fix generated code when libtests contains module 'alloca'.

* pygnulib/GLEmiter.py (GLEmiter.tests_Makefile_am): Use @ALLOCA@ for
libtests.a instead of @LTALLOCA@.
---
 ChangeLog            |  9 +++++++++
 gnulib-tool.py.TODO  | 11 -----------
 pygnulib/GLEmiter.py |  4 ++--
 3 files changed, 11 insertions(+), 13 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index a77eb99cec..a5cc9fd23b 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,12 @@
+2024-02-28  Collin Funk  <collin.fu...@gmail.com>
+
+	gnulib-tool.py: Follow gnulib-tool changes, part 34.
+	Follow gnulib-tool change
+	2017-05-15  Bruno Haible  <br...@clisp.org>
+	gnulib-tool: Fix generated code when libtests contains module 'alloca'.
+	* pygnulib/GLEmiter.py (GLEmiter.tests_Makefile_am): Use @ALLOCA@ for
+	libtests.a instead of @LTALLOCA@.
+
 2024-02-28  Collin Funk  <collin.fu...@gmail.com>
 
 	gnulib-tool.py: Follow gnulib-tool changes, part 33.
diff --git a/gnulib-tool.py.TODO b/gnulib-tool.py.TODO
index 42cccaf71e..cd1274a7be 100644
--- a/gnulib-tool.py.TODO
+++ b/gnulib-tool.py.TODO
@@ -819,17 +819,6 @@ Date:   Sat May 20 13:24:37 2017 +0200
 
 --------------------------------------------------------------------------------
 
-commit 0414a24cf57f1569b0b4f2a0f22898a0943dfc14
-Author: Bruno Haible <br...@clisp.org>
-Date:   Mon May 15 23:13:57 2017 +0200
-
-    gnulib-tool: Fix generated code when libtests contains module 'alloca'.
-
-    * gnulib-tool (func_emit_tests_Makefile_am): For libtests.a, use
-    @ALLOCA@, not @LTALLOCA@.
-
---------------------------------------------------------------------------------
-
 commit f30205c5d59bab2c035165158e7d5d65b07b8363
 Author: Mathieu Lirzin <m...@gnu.org>
 Date:   Tue Mar 14 12:19:40 2017 +0100
diff --git a/pygnulib/GLEmiter.py b/pygnulib/GLEmiter.py
index 260478e5da..dcabc3523c 100644
--- a/pygnulib/GLEmiter.py
+++ b/pygnulib/GLEmiter.py
@@ -993,8 +993,8 @@ AC_DEFUN([%V1%_LIBSOURCES], [
                                           include_guard_prefix)
                 # Check if module is 'alloca'.
                 if libtests and str(module) == 'alloca':
-                    snippet += 'libtests_a_LIBADD += @%sALLOCA@\n' % perhapsLT
-                    snippet += 'libtests_a_DEPENDENCIES += @%sALLOCA@\n' % perhapsLT
+                    snippet += 'libtests_a_LIBADD += @ALLOCA@\n'
+                    snippet += 'libtests_a_DEPENDENCIES += @ALLOCA@\n'
 
                 # Skip the contents if it's entirely empty.
                 if not snippet.isspace():
-- 
2.39.2

From d5aa0cfe26093327d339f763cee18a8e96023310 Mon Sep 17 00:00:00 2001
From: Collin Funk <collin.fu...@gmail.com>
Date: Wed, 28 Feb 2024 22:15:04 -0800
Subject: [PATCH 3/3] gnulib-tool.py: Follow gnulib-tool changes, part 35.

Follow gnulib-tool change
2023-05-28  Bruno Haible  <br...@clisp.org>
warnings, manywarnings: Assume autoconf >= 2.64.

* pygnulib/GLConfig.py (GLConfig.default, GLConfig.getAutoconfVersion)
(GLConfig.setAutoconfVersion, resetAutoconfVersion): Set required
Autoconf version to 2.64.
* pygnulib/GLError.py (GLError.__init__, GLError.__repr__): Likewise.
* pygnulib/GLImport.py (GLImport.__init__): Likewise.
* pygnulib/constants.py (DEFAULT_AUTOCONF_MINVERSION): Likewise.
* pygnulib/main.py: Likewise.
---
 ChangeLog             | 14 ++++++++++++++
 gnulib-tool.py.TODO   | 26 --------------------------
 pygnulib/GLConfig.py  | 10 +++++-----
 pygnulib/GLError.py   |  4 ++--
 pygnulib/GLImport.py  |  2 +-
 pygnulib/constants.py |  4 ++--
 pygnulib/main.py      |  2 +-
 7 files changed, 25 insertions(+), 37 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index a5cc9fd23b..a97282488d 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,17 @@
+2024-02-28  Collin Funk  <collin.fu...@gmail.com>
+
+	gnulib-tool.py: Follow gnulib-tool changes, part 35.
+	Follow gnulib-tool change
+	2023-05-28  Bruno Haible  <br...@clisp.org>
+	warnings, manywarnings: Assume autoconf >= 2.64.
+	* pygnulib/GLConfig.py (GLConfig.default, GLConfig.getAutoconfVersion)
+	(GLConfig.setAutoconfVersion, resetAutoconfVersion): Set required
+	Autoconf version to 2.64.
+	* pygnulib/GLError.py (GLError.__init__, GLError.__repr__): Likewise.
+	* pygnulib/GLImport.py (GLImport.__init__): Likewise.
+	* pygnulib/constants.py (DEFAULT_AUTOCONF_MINVERSION): Likewise.
+	* pygnulib/main.py: Likewise.
+
 2024-02-28  Collin Funk  <collin.fu...@gmail.com>
 
 	gnulib-tool.py: Follow gnulib-tool changes, part 34.
diff --git a/gnulib-tool.py.TODO b/gnulib-tool.py.TODO
index cd1274a7be..d942119be0 100644
--- a/gnulib-tool.py.TODO
+++ b/gnulib-tool.py.TODO
@@ -620,32 +620,6 @@ Date:   Sun Dec 27 01:21:22 2020 +0100
 
 --------------------------------------------------------------------------------
 
-commit 15ce5a630b02af7c7104650dfb18e443b4111564
-Author: Bruno Haible <br...@clisp.org>
-Date:   Sun Aug 16 12:12:32 2020 +0200
-
-    Assume autoconf >= 2.64.
-
-    * gnulib-tool (DEFAULT_AUTOCONF_MINVERSION): Set to 2.64.
-    * DEPENDENCIES: Require Autoconf 2.64 or newer.
-    * NEWS: Mention the changed requirement.
-    * m4/00gnulib.m4 (_m4_divert_diversion, AC_DEFUN_ONCE): Remove macros.
-    * m4/gnulib-common.m4 (AS_VAR_IF, AS_VAR_COPY): Remove macros.
-    * m4/absolute-header.m4 (gl_ABSOLUTE_HEADER): Quote pushdef'ed
-    variables.
-    * m4/include_next.m4 (gl_NEXT_HEADERS_INTERNAL): Likewise.
-    * m4/warn-on-use.m4 (gl_WARN_ON_USE_PREPARE): Likewise.
-    * m4/warnings.m4 (gl_COMPILER_OPTION_IF): Likewise.
-    (gl_UNKNOWN_WARNINGS_ARE_ERRORS(C), gl_UNKNOWN_WARNINGS_ARE_ERRORS(C++),
-    gl_UNKNOWN_WARNINGS_ARE_ERRORS(Objective C)): Define through AC_DEFUN.
-    * m4/manywarnings.m4 (gl_MANYWARN_ALL_GCC(C), gl_MANYWARN_ALL_GCC(C++)):
-    Likewise.
-    * m4/iconv.m4 (AM_ICONV): Define through AC_DEFUN_ONCE directly.
-    * m4/libunistring.m4 (gl_LIBUNISTRING): Likewise.
-    * m4/configmake.m4: Update comment.
-
---------------------------------------------------------------------------------
-
 commit baec1bac1602ba8534320c295e120f7b658400f4
 Author: Bruno Haible <br...@clisp.org>
 Date:   Sat Feb 22 15:15:01 2020 +0100
diff --git a/pygnulib/GLConfig.py b/pygnulib/GLConfig.py
index ae83bd6155..4284c73ad9 100644
--- a/pygnulib/GLConfig.py
+++ b/pygnulib/GLConfig.py
@@ -271,7 +271,7 @@ class GLConfig(object):
             elif key == 'include_guard_prefix':
                 return 'GL'
             elif key == 'ac_version':
-                return 2.59
+                return 2.64
             elif key == 'verbosity':
                 return 0
             elif key in ['modules', 'avoids', 'tests', 'incl_test_categories', 'excl_test_categories']:
@@ -943,11 +943,11 @@ class GLConfig(object):
 
     # Define ac_version methods.
     def getAutoconfVersion(self):
-        '''Return preferred autoconf version. Default value is 2.59.'''
+        '''Return preferred autoconf version. Default value is 2.64.'''
         return self.table['ac_version']
 
     def setAutoconfVersion(self, ac_version):
-        '''Specify preferred autoconf version. Default value is 2.59.'''
+        '''Specify preferred autoconf version. Default value is 2.64.'''
         if type(ac_version) is float or type(ac_version) is int:
             self.table['ac_version'] = float(ac_version)
         else:  # if ac_version has not int or float type
@@ -955,8 +955,8 @@ class GLConfig(object):
                             % type(ac_version).__name__)
 
     def resetAutoconfVersion(self):
-        '''Specify preferred autoconf version. Default value is 2.59.'''
-        self.table['ac_version'] = 2.59
+        '''Specify preferred autoconf version. Default value is 2.64.'''
+        self.table['ac_version'] = 2.64
 
     # Define symbolic methods.
     def checkSymbolic(self):
diff --git a/pygnulib/GLError.py b/pygnulib/GLError.py
index bd8b3b2956..5c7420e8b1 100644
--- a/pygnulib/GLError.py
+++ b/pygnulib/GLError.py
@@ -45,7 +45,7 @@ class GLError(Exception):
           1: file does not exist in GLFileSystem: <file>
           2: cannot patch file inside GLFileSystem: <file>
           3: configure file does not exist: <configure.ac>
-          4: minimum supported autoconf version is 2.59, not <version>
+          4: minimum supported autoconf version is 2.64, not <version>
           5: <gnulib-comp.m4> is expected to contain gl_M4_BASE([<m4base>])
           6: missing sourcebase argument
           7: missing docbase argument
@@ -78,7 +78,7 @@ class GLError(Exception):
             elif errno == 3:
                 message = "configure file does not exist: %s" % repr(errinfo)
             elif errno == 4:
-                message = "minimum supported autoconf version is 2.59, not %s" % repr(errinfo)
+                message = "minimum supported autoconf version is 2.64, not %s" % repr(errinfo)
             elif errno == 5:
                 message = "%s is expected to contain gl_M4_BASE([%s])" % (repr(os.path.join(errinfo, 'gnulib-comp.m4')), repr(errinfo))
             elif errno == 6:
diff --git a/pygnulib/GLImport.py b/pygnulib/GLImport.py
index fca2333ec5..e18a9601ec 100644
--- a/pygnulib/GLImport.py
+++ b/pygnulib/GLImport.py
@@ -112,7 +112,7 @@ class GLImport(object):
             version = sorted(set([ float(version)
                                    for version in versions ]))[-1]
             self.config.setAutoconfVersion(version)
-            if version < 2.59:
+            if version < 2.64:
                 raise GLError(4, version)
 
         # Get other cached variables.
diff --git a/pygnulib/main.py b/pygnulib/main.py
index 443300c439..93fd637f24 100644
--- a/pygnulib/main.py
+++ b/pygnulib/main.py
@@ -1210,7 +1210,7 @@ if __name__ == '__main__':
             elif errno == 3:
                 message += 'cannot find %s - make sure you run gnulib-tool from within your package\'s directory' % errinfo
             elif errno == 4:
-                message += 'minimum supported autoconf version is 2.59. Try adding'
+                message += 'minimum supported autoconf version is 2.64. Try adding'
                 message += 'AC_PREREQ([%s])' % constants.DEFAULT_AUTOCONF_MINVERSION
                 message += ' to your configure.ac.'
             elif errno == 5:
diff --git a/pygnulib/constants.py b/pygnulib/constants.py
index 22430f0df3..0f6f5c67f0 100644
--- a/pygnulib/constants.py
+++ b/pygnulib/constants.py
@@ -121,8 +121,8 @@ TESTS = \
     }
 
 # Define AUTOCONF minimum version
-DEFAULT_AUTOCONF_MINVERSION = 2.59
-# You can set AUTOCONFPATH to empty if autoconf 2.57 is already in your PATH
+DEFAULT_AUTOCONF_MINVERSION = 2.64
+# You can set AUTOCONFPATH to empty if autoconf 2.64 is already in your PATH
 AUTOCONFPATH = ''
 # You can set AUTOMAKEPATH to empty if automake 1.9.x is already in your PATH
 AUTOMAKEPATH = ''
-- 
2.39.2

Reply via email to